/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.adl;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.BindingController;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Abstract Checker component using delegation. The
 * {@link Checker#check(Object, Object) check }method first call the client
 * interface (if bound) then call the {@link #doChek(Object, Object) }method.
 */
public abstract class AbstractDelagatingChecker
    implements
      Checker,
      BindingController
{

  /** The name of the optionnal client interface used for delegation */
  public static final String CHECKER_OPT_ITF_NAME = "client-checker";

  protected Checker          optChekerItf;

  /**
   * @see org.objectweb.dream.adl.Checker#check(java.lang.Object,
   *      java.lang.Object)
   */
  public void check(Object legacyComponent, Object node) throws ADLException
  {
    if (optChekerItf != null)
    {
      optChekerItf.check(legacyComponent, node);
    }
    doChek(legacyComponent, node);
  }

  protected abstract void doChek(Object legacyComponent, Object node)
      throws ADLException;

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{CHECKER_OPT_ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#lookupFc(java.lang.String)
   */
  public Object lookupFc(String clientItfName) throws NoSuchInterfaceException
  {
    if (CHECKER_OPT_ITF_NAME.equals(clientItfName))
    {
      return optChekerItf;
    }
    return null;
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(java.lang.String,
   *      java.lang.Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    if (CHECKER_OPT_ITF_NAME.equals(clientItfName))
    {
      optChekerItf = (Checker) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#unbindFc(java.lang.String)
   */
  public void unbindFc(String clientItfName) throws NoSuchInterfaceException,
      IllegalBindingException, IllegalLifeCycleException
  {
    if (CHECKER_OPT_ITF_NAME.equals(clientItfName))
    {
      optChekerItf = null;
    }
  }

}