/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.adl.legacy;

import org.objectweb.fractal.adl.components.FractalComponentBuilder;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.ContentController;
import org.objectweb.fractal.util.Fractal;

/**
 * Component builder for legacy component. Adds the
 * {@link LegacyComponentBuilder#stopComponent(Object, Object) stopComponent }
 * method and the
 * {@link org.objectweb.fractal.adl.components.ComponentBuilder#addComponent(Object, Object, String, Object) addComponent }
 * method check if the sub component is not already in the super component (in
 * case of legacy component)
 */
public class FractalLegacyComponentBuilder extends FractalComponentBuilder
    implements
      LegacyComponentBuilder
{

  /**
   * @see LegacyComponentBuilder#stopComponent(Object, Object)
   */
  public void stopComponent(Object component, Object context) throws Exception
  {
    /*
     * try { Fractal.getLifeCycleController((Component) component).stopFc(); }
     * catch (NoSuchInterfaceException ignored) { } catch (NullPointerException
     * ignored) { }
     */
  }

  /**
   * @see org.objectweb.fractal.adl.components.ComponentBuilder#addComponent(Object,
   *      Object, String, Object)
   */
  public void addComponent(Object superComponent, Object subComponent,
      String name, Object context) throws Exception
  {
    ContentController cc = Fractal
        .getContentController((Component) superComponent);
    Component subComponents[] = cc.getFcSubComponents();
    for (int i = 0; i < subComponents.length; i++)
    {
      if (subComponents[i] == subComponent)
      {
        // subComponent already a sub component of superComponent.
        return;
      }
    }
    cc.addFcSubComponent((Component) subComponent);
    try
    {
      Fractal.getNameController((Component) subComponent).setFcName(name);
    }
    catch (NoSuchInterfaceException ignored)
    {
    }
  }
}